==> hibiscus.js-1.2.1.tgz: package/select/option-li.component.js <==
import { Component, ElementRef, Input } from '@angular/core';
import { OptionComponent } from './option.component';
var OptionLiComponent = /** @class */ (function () {
    function OptionLiComponent(elementRef) {
        this.elementRef = elementRef;
        this.selected = false;
        this.active = false;
        this.hiShowActive = true;
        this.el = elementRef.nativeElement;
    }
    Object.defineProperty(OptionLiComponent.prototype, "hiActiveOption", {
        set: function (value) {
            if (value) {
                this.active = this.compareWith(value.hiValue, this.hiOption.hiValue);
            }
            else {
                this.active = false;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OptionLiComponent.prototype, "hiListOfSelectedValue", {
        set: 
        // tslint:disable-next-line:no-any
        function (valueList) {
            var _this = this;
            this.selected = valueList.find(function (v) { return _this.compareWith(v, _this.hiOption.hiValue); });
        },
        enumerable: true,
        configurable: true
    });
    OptionLiComponent.decorators = [
        { type: Component, args: [{
                    selector: '[hi-option-li]',
                    template: "\n    <ng-container *ngIf=\"hiOption.hiCustomContent\">\n      <ng-template [ngTemplateOutlet]=\"hiOption.template\"></ng-template>\n    </ng-container>\n    <ng-container *ngIf=\"!hiOption.hiCustomContent\">\n      {{hiOption.hiLabel}}\n    </ng-container>\n  ",
                    host: {
                        '[class.hi-select-dropdown-menu-item]': 'true',
                        '[class.hi-select-dropdown-menu-item-selected]': 'selected && !hiOption.hiDisabled',
                        '[class.hi-select-dropdown-menu-item-disabled]': 'hiOption.hiDisabled',
                        '[class.hi-select-dropdown-menu-item-active]': 'active && !hiOption.hiDisabled && hiShowActive && !selected',
                        '[attr.unselectable]': '"unselectable"',
                        '[style.user-select]': '"none"'
                    }
                },] },
    ];
    /** @nocollapse */
    OptionLiComponent.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    OptionLiComponent.propDecorators = {
        "hiOption": [{ type: Input },],
        "hiShowActive": [{ type: Input },],
        "compareWith": [{ type: Input },],
        "hiActiveOption": [{ type: Input },],
        "hiListOfSelectedValue": [{ type: Input },],
    };
    return OptionLiComponent;
}());
export { OptionLiComponent };

==> hibiscus.js-1.2.3.tgz: package/select/option-li.component.js <==
import { Component, ElementRef, Input } from '@angular/core';
import { OptionComponent } from './option.component';
var OptionLiComponent = (function () {
    function OptionLiComponent(elementRef) {
        this.elementRef = elementRef;
        this.selected = false;
        this.active = false;
        this.hiShowActive = true;
        this.el = elementRef.nativeElement;
    }
    Object.defineProperty(OptionLiComponent.prototype, "hiActiveOption", {
        set: function (value) {
            if (value) {
                this.active = this.compareWith(value.hiValue, this.hiOption.hiValue);
            }
            else {
                this.active = false;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(OptionLiComponent.prototype, "hiListOfSelectedValue", {
        set: function (valueList) {
            var _this = this;
            this.selected = valueList.find(function (v) { return _this.compareWith(v, _this.hiOption.hiValue); });
        },
        enumerable: true,
        configurable: true
    });
    OptionLiComponent.decorators = [
        { type: Component, args: [{
                    selector: '[hi-option-li]',
                    template: "\n    <ng-container *ngIf=\"hiOption.hiCustomContent\">\n      <ng-template [ngTemplateOutlet]=\"hiOption.template\"></ng-template>\n    </ng-container>\n    <ng-container *ngIf=\"!hiOption.hiCustomContent\">\n      {{hiOption.hiLabel}}\n    </ng-container>\n  ",
                    host: {
                        '[class.hi-select-dropdown-menu-item]': 'true',
                        '[class.hi-select-dropdown-menu-item-selected]': 'selected && !hiOption.hiDisabled',
                        '[class.hi-select-dropdown-menu-item-disabled]': 'hiOption.hiDisabled',
                        '[class.hi-select-dropdown-menu-item-active]': 'active && !hiOption.hiDisabled && hiShowActive && !selected',
                        '[attr.unselectable]': '"unselectable"',
                        '[style.user-select]': '"none"'
                    }
                },] },
    ];
    OptionLiComponent.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    OptionLiComponent.propDecorators = {
        "hiOption": [{ type: Input },],
        "hiShowActive": [{ type: Input },],
        "compareWith": [{ type: Input },],
        "hiActiveOption": [{ type: Input },],
        "hiListOfSelectedValue": [{ type: Input },],
    };
    return OptionLiComponent;
}());
export { OptionLiComponent };
